@@ -1,12 +1,11 @@
 package Hailo::Test;
-our $VERSION = '0.28';
+our $VERSION = '0.29';
 use 5.010;
 use autodie;
 use Any::Moose;
 use Hailo;
 use Test::More;
 use File::Spec::Functions qw(catfile);
-use Data::Random qw(:all);
 use File::Slurp qw(slurp);
 use List::Util qw(shuffle min);
 use File::Temp qw(tempfile tempdir);
@@ -261,8 +260,9 @@ sub train_a_few_tokens {
     my $hailo = $self->hailo;
 
     # Get some training material
-    my $size = 10;
-    my @random_tokens = rand_chars( set => 'all', min => 10, max => 15 );
+
+    my @chr = map { chr } 50..120;
+    my @random_tokens = map { $chr[rand @chr] } 1 .. 30;
 
     # Learn from it
     if ((int rand 2) == 1) {
